Documentation
¶
Index ¶
- Constants
- Variables
- type AuthConfig
- type CacheConfig
- type CertSpec
- type Config
- type DatabaseConfig
- type GRPCConfig
- type JWTConfig
- type LocalCacheConfig
- type MetricsConfig
- type MysqlConfig
- type MysqlTLSConfig
- type NetworkConfig
- type ObjectStorageConfig
- type PostgresConfig
- type RESTConfig
- type RESTTLSConfig
- type RedisCacheConfig
- type RedisConfig
- type SecurityConfig
- type ServerConfig
- type TCPListenPortRange
- type TrainerConfig
Constants ¶
const ( AttributeID = attribute.Key("d7y.manager.id") AttributePreheatType = attribute.Key("d7y.manager.preheat.type") AttributePreheatURL = attribute.Key("d7y.manager.preheat.url") )
const ( SpanPreheat = "preheat" SpanGetLayers = "get-layers" SpanAuthWithRegistry = "auth-with-registry" )
const ( // DatabaseTypeMysql is database type of mysql. DatabaseTypeMysql = "mysql" // DatabaseTypeMariaDB is database type of mariadb. DatabaseTypeMariaDB = "mariadb" // DatabaseTypePostgres is database type of postgres. DatabaseTypePostgres = "postgres" )
const ( // DefaultServerName is default server name. DefaultServerName = "d7y/manager" // DefaultGRPCPort is default port for grpc server. DefaultGRPCPort = 65003 // DefaultGRPCPort is default port for grpc server. DefaultGRPCAdvertisePort = 65003 // DefaultRESTAddr is default address for rest server. DefaultRESTAddr = ":8080" )
const ( // DefaultJWTTimeout is default of name in jwt. DefaultJWTRealm = "Dragonfly" // DefaultJWTTimeout is default of timeout in jwt. DefaultJWTTimeout = 2 * 24 * time.Hour // DefaultJWTMaxRefresh is default of max refresh in jwt. DefaultJWTMaxRefresh = 2 * 24 * time.Hour )
const ( // DefaultRedisDB is default db for redis. DefaultRedisDB = 0 // DefaultRedisBrokerDB is default db for redis broker. DefaultRedisBrokerDB = 1 // DefaultRedisBackendDB is default db for redis backend. DefaultRedisBackendDB = 2 )
const ( // DefaultRedisCacheTTL is default ttl for redis cache. DefaultRedisCacheTTL = 5 * time.Minute // DefaultLFUCacheTTL is default ttl for lfu cache. DefaultLFUCacheTTL = 3 * time.Minute // DefaultLFUCacheSize is default size for lfu cache. DefaultLFUCacheSize = 200 * 1000 )
const ( // DefaultMysqlPort is default port for mysql. DefaultMysqlPort = 3306 // DefaultMysqlDBName is default db name for mysql. DefaultMysqlDBName = "manager" )
const ( // DefaultPostgresPort is default port for postgres. DefaultPostgresPort = 5432 // DefaultPostgresDBName is default db name for postgres. DefaultPostgresDBName = "manager" // DefaultPostgresSSLMode is default ssl mode for postgres. DefaultPostgresSSLMode = "disable" // DefaultPostgresTimezone is default timezone for postgres. DefaultPostgresTimezone = "UTC" )
const (
// DefaultMetricsAddr is default address for metrics server.
DefaultMetricsAddr = ":8000"
)
Variables ¶
var ( // DefaultCertIPAddresses is default ip addresses of certificate. DefaultCertIPAddresses = []net.IP{ip.IPv4, ip.IPv6} // DefaultCertDNSNames is default dns names of certificate. DefaultCertDNSNames = []string{"dragonfly-manager", "dragonfly-manager.dragonfly-system.svc", "dragonfly-manager.dragonfly-system.svc.cluster.local"} // DefaultCertValidityPeriod is default validity period of certificate. DefaultCertValidityPeriod = 10 * 365 * 24 * time.Hour )
var ( // DefaultNetworkEnableIPv6 is default value of enableIPv6. DefaultNetworkEnableIPv6 = false )
var (
// DefaultTrainerBucketName is default object storage bucket name of model.
DefaultTrainerBucketName = "models"
)
Functions ¶
This section is empty.
Types ¶
type AuthConfig ¶
type AuthConfig struct {
// JWT configuration.
JWT JWTConfig `yaml:"jwt" mapstructure:"jwt"`
}
type CacheConfig ¶
type CacheConfig struct {
// Redis cache configuration.
Redis RedisCacheConfig `yaml:"redis" mapstructure:"redis"`
// Local cache configuration.
Local LocalCacheConfig `yaml:"local" mapstructure:"local"`
}
type CertSpec ¶
type CertSpec struct {
// DNSNames is a list of dns names be set on the certificate.
DNSNames []string `mapstructure:"dnsNames" yaml:"dnsNames"`
// IPAddresses is a list of ip addresses be set on the certificate.
IPAddresses []net.IP `mapstructure:"ipAddresses" yaml:"ipAddresses"`
// ValidityPeriod is the validity period of certificate.
ValidityPeriod time.Duration `mapstructure:"validityPeriod" yaml:"validityPeriod"`
}
type Config ¶
type Config struct {
// Base options.
base.Options `yaml:",inline" mapstructure:",squash"`
// Server configuration.
Server ServerConfig `yaml:"server" mapstructure:"server"`
// Auth configuration.
Auth AuthConfig `yaml:"auth" mapstructure:"auth"`
// Database configuration.
Database DatabaseConfig `yaml:"database" mapstructure:"database"`
// Cache configuration.
Cache CacheConfig `yaml:"cache" mapstructure:"cache"`
// ObjectStorage configuration.
ObjectStorage ObjectStorageConfig `yaml:"objectStorage" mapstructure:"objectStorage"`
// Metrics configuration.
Metrics MetricsConfig `yaml:"metrics" mapstructure:"metrics"`
// Security configuration.
Security SecurityConfig `yaml:"security" mapstructure:"security"`
// Network configuration.
Network NetworkConfig `yaml:"network" mapstructure:"network"`
// Trainer configuration.
Trainer TrainerConfig `yaml:"trainer" mapstructure:"trainer"`
}
type DatabaseConfig ¶
type DatabaseConfig struct {
// Database type.
Type string `yaml:"type" mapstructure:"type"`
// Mysql configuration.
Mysql MysqlConfig `yaml:"mysql" mapstructure:"mysql"`
// Postgres configuration.
Postgres PostgresConfig `yaml:"postgres" mapstructure:"postgres"`
// Redis configuration.
Redis RedisConfig `yaml:"redis" mapstructure:"redis"`
}
type GRPCConfig ¶
type GRPCConfig struct {
// AdvertiseIP is advertise ip.
AdvertiseIP net.IP `yaml:"advertiseIP" mapstructure:"advertiseIP"`
// AdvertisePort is advertise port.
AdvertisePort int `yaml:"advertisePort" mapstructure:"advertisePort"`
// ListenIP is listen ip, like: 0.0.0.0, 192.168.0.1.
ListenIP net.IP `mapstructure:"listenIP" yaml:"listenIP"`
// Port is listen port.
PortRange TCPListenPortRange `yaml:"port" mapstructure:"port"`
}
type JWTConfig ¶
type JWTConfig struct {
// Realm name to display to the user, default value is Dragonfly.
Realm string `yaml:"realm" mapstructure:"realm"`
// Key is secret key used for signing. Please change the key in production
Key string `yaml:"key" mapstructure:"key"`
// Timeout is duration that a jwt token is valid, default duration is two days.
Timeout time.Duration `yaml:"timeout" mapstructure:"timeout"`
// MaxRefresh field allows clients to refresh their token until MaxRefresh has passed, default duration is two days.
MaxRefresh time.Duration `yaml:"maxRefresh" mapstructure:"maxRefresh"`
}
type LocalCacheConfig ¶
type MetricsConfig ¶
type MysqlConfig ¶
type MysqlConfig struct {
// Server username.
User string `yaml:"user" mapstructure:"user"`
// Server password.
Password string `yaml:"password" mapstructure:"password"`
// Server host.
Host string `yaml:"host" mapstructure:"host"`
// Server port.
Port int `yaml:"port" mapstructure:"port"`
// Server DB name.
DBName string `yaml:"dbname" mapstructure:"dbname"`
// TLS mode (can be one of "true", "false", "skip-verify", or "preferred").
TLSConfig string `yaml:"tlsConfig" mapstructure:"tlsConfig"`
// Custom TLS configuration (overrides "TLSConfig" setting above).
TLS *MysqlTLSConfig `yaml:"tls" mapstructure:"tls"`
// Enable migration.
Migrate bool `yaml:"migrate" mapstructure:"migrate"`
}
type MysqlTLSConfig ¶
type MysqlTLSConfig struct {
// Client certificate file path.
Cert string `yaml:"cert" mapstructure:"cert"`
// Client key file path.
Key string `yaml:"key" mapstructure:"key"`
// CA file path.
CA string `yaml:"ca" mapstructure:"ca"`
// InsecureSkipVerify controls whether a client verifies the
// server's certificate chain and host name.
InsecureSkipVerify bool `yaml:"insecureSkipVerify" mapstructure:"insecureSkipVerify"`
}
type NetworkConfig ¶
type NetworkConfig struct {
// EnableIPv6 enables ipv6 for server.
EnableIPv6 bool `mapstructure:"enableIPv6" yaml:"enableIPv6"`
}
type ObjectStorageConfig ¶
type ObjectStorageConfig struct {
// Enable object storage.
Enable bool `yaml:"enable" mapstructure:"enable"`
// Name is object storage name of type, it can be s3, oss or obs.
Name string `mapstructure:"name" yaml:"name"`
// Region is storage region.
Region string `mapstructure:"region" yaml:"region"`
// Endpoint is datacenter endpoint.
Endpoint string `mapstructure:"endpoint" yaml:"endpoint"`
// AccessKey is access key ID.
AccessKey string `mapstructure:"accessKey" yaml:"accessKey"`
// SecretKey is access key secret.
SecretKey string `mapstructure:"secretKey" yaml:"secretKey"`
// S3ForcePathStyle sets force path style for s3, true by default.
// Set this to `true` to force the request to use path-style addressing,
// i.e., `http://s3.amazonaws.com/BUCKET/KEY`. By default, the S3 client
// will use virtual hosted bucket addressing when possible
// (`http://BUCKET.s3.amazonaws.com/KEY`).
// Refer to https://github.com/aws/aws-sdk-go/blob/main/aws/config.go#L118.
S3ForcePathStyle bool `mapstructure:"s3ForcePathStyle" yaml:"s3ForcePathStyle"`
}
type PostgresConfig ¶
type PostgresConfig struct {
// Server username.
User string `yaml:"user" mapstructure:"user"`
// Server password.
Password string `yaml:"password" mapstructure:"password"`
// Server host.
Host string `yaml:"host" mapstructure:"host"`
// Server port.
Port int `yaml:"port" mapstructure:"port"`
// Server DB name.
DBName string `yaml:"dbname" mapstructure:"dbname"`
// SSL mode.
SSLMode string `yaml:"sslMode" mapstructure:"sslMode"`
// Server timezone.
Timezone string `yaml:"timezone" mapstructure:"timezone"`
// Enable migration.
Migrate bool `yaml:"migrate" mapstructure:"migrate"`
}
type RESTConfig ¶
type RESTConfig struct {
// REST server address.
Addr string `yaml:"addr" mapstructure:"addr"`
// TLS configuration.
TLS *RESTTLSConfig `yaml:"tls" mapstructure:"tls"`
}
type RESTTLSConfig ¶
type RedisCacheConfig ¶
type RedisConfig ¶
type RedisConfig struct {
// DEPRECATED: Please use the `addrs` field instead.
Host string `yaml:"host" mapstructure:"host"`
// DEPRECATED: Please use the `addrs` field instead.
Port int `yaml:"port" mapstructure:"port"`
// Addrs is server addresses.
Addrs []string `yaml:"addrs" mapstructure:"addrs"`
// MasterName is the sentinel master name.
MasterName string `yaml:"masterName" mapstructure:"masterName"`
// Username is server username.
Username string `yaml:"username" mapstructure:"username"`
// Password is server password.
Password string `yaml:"password" mapstructure:"password"`
// DB is server cache DB name.
DB int `yaml:"db" mapstructure:"db"`
// BrokerDB is server broker DB name.
BrokerDB int `yaml:"brokerDB" mapstructure:"brokerDB"`
// BackendDB is server backend DB name.
BackendDB int `yaml:"backendDB" mapstructure:"backendDB"`
}
type SecurityConfig ¶
type SecurityConfig struct {
// AutoIssueCert indicates to issue client certificates for all grpc call.
AutoIssueCert bool `yaml:"autoIssueCert" mapstructure:"autoIssueCert"`
// CACert is the CA certificate for all grpc tls handshake, it can be path or PEM format string.
CACert types.PEMContent `mapstructure:"caCert" yaml:"caCert"`
// CAKey is the CA private key, it can be path or PEM format string.
CAKey types.PEMContent `mapstructure:"caKey" yaml:"caKey"`
// TLSPolicy controls the grpc shandshake behaviors:
// force: both ClientHandshake and ServerHandshake are only support tls
// prefer: ServerHandshake supports tls and insecure (non-tls), ClientHandshake will only support tls
// default: ServerHandshake supports tls and insecure (non-tls), ClientHandshake will only support insecure (non-tls)
TLSPolicy string `mapstructure:"tlsPolicy" yaml:"tlsPolicy"`
// CertSpec is the desired state of certificate.
CertSpec CertSpec `mapstructure:"certSpec" yaml:"certSpec"`
}
type ServerConfig ¶
type ServerConfig struct {
// Server name.
Name string `yaml:"name" mapstructure:"name"`
// Server work directory.
WorkHome string `yaml:"workHome" mapstructure:"workHome"`
// Server dynamic config cache directory.
CacheDir string `yaml:"cacheDir" mapstructure:"cacheDir"`
// Server log directory.
LogDir string `yaml:"logDir" mapstructure:"logDir"`
// Server plugin directory.
PluginDir string `yaml:"pluginDir" mapstructure:"pluginDir"`
// GRPC server configuration.
GRPC GRPCConfig `yaml:"grpc" mapstructure:"grpc"`
// REST server configuration.
REST RESTConfig `yaml:"rest" mapstructure:"rest"`
}
type TCPListenPortRange ¶
type TrainerConfig ¶
Click to show internal directories.
Click to hide internal directories.